@@ -1,20 +1,15 @@
 #include "tintin.h"
-#include "ui.h"
 #include "protos/colors.h"
+#include "protos/globals.h"
 #include "protos/unicode.h"
+#include "protos/user.h"
 #include "protos/utils.h"
 
 
-mbstate_t outstate;
+static mbstate_t outstate;
 #define OUTSTATE &outstate
-extern void user_illegal();
-extern void user_noop();
-extern int need_resize;
-
-
 static char *i_pos;
 
-
 static void userpipe_init(void)
 {
     tty=isatty(1);
@@ -23,20 +18,20 @@ static void userpipe_init(void)
     memset(&outstate, 0, sizeof(outstate));
 }
 
-static void userpipe_textout(char *txt)
+static void userpipe_textout(const char *txt)
 {
-    char buf[BUFFER_SIZE],*a,*b;
+    char buf[BUFFER_SIZE], *b=buf;
 
-    for (a=txt,b=buf; *a; )
+    for (const char *a=txt; *a; )
         switch (*a)
         {
         case '~':
-            if (getcolor(&a,&color,1))
+            if (getcolor(&a, &color, 1))
             {
                 if (color==-1)
                     color=lastcolor;
                 if (tty)
-                    b+=sprintf(b,COLORCODE(color));
+                    b=ansicolor(b, color);
             }
             else
                 *b++='~';
@@ -47,10 +42,10 @@ static void userpipe_textout(char *txt)
         default:
             one_utf8_to_mb(&b, &a, &outstate);
         }
-    write_stdout(buf,b-buf);
+    write_stdout(buf, b-buf);
 }
 
-static int userpipe_process_kbd(struct session *ses, WC ch)
+static bool userpipe_process_kbd(struct session *ses, WC ch)
 {
 
     switch (ch)
@@ -58,54 +53,67 @@ static int userpipe_process_kbd(struct session *ses, WC ch)
     case '\n':
         *i_pos=0;
         i_pos=done_input;
-        return 1;
+        return true;
     case 8:
         if (i_pos!=done_input)
             i_pos--;
-        return 0;
+        return false;
     default:
         if (i_pos-done_input>=BUFFER_SIZE-8)
-            return 0;
+            return false;
         i_pos+=wc_to_utf8(i_pos, &ch, 1, BUFFER_SIZE-(i_pos-done_input));
     case 0:
         ;
     }
-    return 0;
+    return false;
 }
 
 static void userpipe_beep(void)
 {
-    write_stdout("\007",1);
+    write_stdout("\007", 1);
     /* should it beep if we're redirected to a pipe? */
 }
 
+static void userpipe_passwd(bool x)
+{
+    // TODO: stty echo off?
+}
+
 static void userpipe_resize(void)
 {
-    need_resize=0;
+    need_resize=false;
 }
 
-void userpipe_initdriver()
+static void user_illegal(void)
 {
-    ui_sep_input=0;
-    ui_con_buffer=0;
-    ui_keyboard=0;
-    ui_own_output=0;
-    ui_tty=1;
-    ui_drafts=0;
+    syserr("DRIVER: operation not supported");
+}
+
+static void user_noop(void)
+{
+}
+
+void userpipe_initdriver(void)
+{
+    ui_sep_input=false;
+    ui_con_buffer=false;
+    ui_keyboard=false;
+    ui_own_output=false;
+    ui_drafts=false;
 
     user_init           = userpipe_init;
     user_done           = user_noop;
     user_pause          = user_illegal;
     user_resume         = user_illegal;
     user_textout        = userpipe_textout;
-    user_textout_draft  = user_noop;
+    user_textout_draft  = (void (*)(const char*, bool))user_noop;
     user_process_kbd    = userpipe_process_kbd;
     user_beep           = userpipe_beep;
-    user_keypad         = user_illegal;
+    user_keypad         = (void (*)(bool))user_illegal;
     user_retain         = user_illegal;
-    user_passwd         = user_noop;
-    user_condump        = user_illegal;
-    user_title          = (printffunc*)user_illegal;
+    user_passwd         = userpipe_passwd;
+    user_condump        = (void (*)(FILE *))user_illegal;
+    user_title          = (void (*)(const char*, ...))user_illegal;
     user_resize         = userpipe_resize;
     user_show_status    = user_illegal;
     user_mark_greeting  = user_noop;
